@@ -46,7 +46,7 @@ class CarClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateSession(self, request):
@@ -69,7 +69,7 @@ class CarClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DestroySession(self, request):
@@ -92,4 +92,50 @@ class CarClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StartPublishStream(self, request):
+        """开始云端推流
+
+        :param request: Request instance for StartPublishStream.
+        :type request: :class:`tencentcloud.car.v20220110.models.StartPublishStreamRequest`
+        :rtype: :class:`tencentcloud.car.v20220110.models.StartPublishStreamResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartPublishStream", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartPublishStreamResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StopPublishStream(self, request):
+        """停止云端推流
+
+        :param request: Request instance for StopPublishStream.
+        :type request: :class:`tencentcloud.car.v20220110.models.StopPublishStreamRequest`
+        :rtype: :class:`tencentcloud.car.v20220110.models.StopPublishStreamResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopPublishStream", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopPublishStreamResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
